@@ -23,7 +23,7 @@ def get_target_color(img):
 class ImageLayer:
     def __init__(self, image, pixelcoords, color):
         self.pxcs = set(pixelcoords)
-        self.color = tuple(color)
+        self.color = color if type(color) == int else tuple(color)
         self.image = image
     
     def add_pixel(self, x, y):
